==> haskell-invariant-0.6.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-BPUh7ZoRt4N7qthyMZi4Ss
key:                  invariant-0.6.4-BPUh7ZoRt4N7qthyMZi4Ss
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  96b3edc5de89063394366ac41fde6107
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-BPUh7ZoRt4N7qthyMZi4Ss
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6-5KrJJWXN6lQKV6QHE4OSXU
    comonad-5.0.9-178kmWrlefq4Vhns6stMp9 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.2-LJ401T2PttGGl9FwS0VQ4N stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-4tF6VC1d0ODJ0H7AFNioZw

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-98AENB7ebJi4VT6kS5zVow
key:                  invariant-0.6.4-98AENB7ebJi4VT6kS5zVow
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  228e772d04a7dd1dea3f843e9bad8c8a
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-98AENB7ebJi4VT6kS5zVow
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6-JjED7nnAOkT7R8WbyLEBEb
    comonad-5.0.9-2mlbieWEMFVLKIv0ZWjyXF containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.2-AiDxHaQJy5tBUJhePOzhm6 stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-6j2GAGNbaJu7CXoZ5IjX0N

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
